# Model Feature Scan Report

_Report generated on: 2025-06-04T14:30:59.548436_

## API: AnthropicApi

### API Summary

* **Total Models Scanned:** 22
* **Average Supported Features per Model:** 4.09

#### Feature Support Across Models:

* Audio: 0.0% (0/22)
* AudioConversion: 0.0% (0/22)
* AudioEmbeddings: 0.0% (0/22)
* AudioGeneration: 0.0% (0/22)
* AudioTranscription: 4.5% (1/22)
* Document: 59.1% (13/22)
* DocumentConversion: 0.0% (0/22)
* DocumentEmbeddings: 0.0% (0/22)
* Image: 72.7% (16/22)
* ImageConversion: 0.0% (0/22)
* ImageEmbeddings: 0.0% (0/22)
* ImageGeneration: 0.0% (0/22)
* StructuredTextGeneration: 77.3% (17/22)
* TextEmbeddings: 4.5% (1/22)
* TextGeneration: 77.3% (17/22)
* Thinking: 40.9% (9/22)
* Tools: 72.7% (16/22)
* Video: 0.0% (0/22)
* VideoConversion: 0.0% (0/22)
* VideoEmbeddings: 0.0% (0/22)
* VideoGeneration: 0.0% (0/22)

### Model Details

#### Model: claude-2.0 (2/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: claude-2.1 (0/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: claude-3-5-haiku-20241022 (5/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ✅ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: claude-3-5-sonnet-20240620 (5/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ✅ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: claude-3-5-sonnet-20241022 (5/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ✅ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: claude-3-7-sonnet-20250219 (5/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ✅ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: claude-3-7-sonnet-20250219-thinking-high (6/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ✅ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ✅ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: claude-3-7-sonnet-20250219-thinking-low (6/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ✅ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ✅ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: claude-3-7-sonnet-20250219-thinking-mid (6/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ✅ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ✅ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: claude-3-haiku-20240307 (4/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: claude-3-opus-20240229 (4/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: claude-3-sonnet-20240229 (4/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: claude-opus-4-20250514 (5/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ✅ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: claude-opus-4-20250514-thinking-high (6/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ✅ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ✅ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: claude-opus-4-20250514-thinking-low (1/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ✅ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: claude-opus-4-20250514-thinking-mid (6/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ✅ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ✅ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: claude-sonnet-4-20250514 (5/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ✅ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: claude-sonnet-4-20250514-thinking-high (6/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ✅ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ✅ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: claude-sonnet-4-20250514-thinking-low (1/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ✅ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: claude-sonnet-4-20250514-thinking-mid (6/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ✅ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ✅ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: fastembed (1/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ✅ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: whisper-local (1/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ✅ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

_This report is auto-generated by Litemind. Some features may not be supported due to model limitations, API
restrictions, or potential bugs in Litemind._